@@ -20,7 +20,7 @@ double rcpptest1_cai11(arma::mat& X){
   double hXiXj = 0;
   for (int j=1;j<n;j++){
     Xj = X.row(j);
-    for (int i=0;i<(j-1);i++){
+    for (int i=0;i<j;i++){
       Xi = X.row(i);
       hXiXj += std::pow(dot(Xi,Xj),2)-(dot(Xi,Xi)+dot(Xj,Xj)) + p;
     }
